@@ -1,28 +1,41 @@
 package resources
 
 import (
-	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/aws/session"
-	"github.com/aws/aws-sdk-go/service/appconfig"
-	"github.com/rebuy-de/aws-nuke/v2/pkg/types"
+	"context"
+
 	"github.com/sirupsen/logrus"
+
+	"github.com/aws/aws-sdk-go/aws"
+	"github.com/aws/aws-sdk-go/service/appconfig"
+
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
+	"github.com/ekristen/libnuke/pkg/types"
+
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
 )
 
-type AppConfigHostedConfigurationVersion struct {
-	svc                    *appconfig.AppConfig
-	applicationId          *string
-	configurationProfileId *string
-	versionNumber          *int64
-}
+const AppConfigHostedConfigurationVersionResource = "AppConfigHostedConfigurationVersion"
 
 func init() {
-	register("AppConfigHostedConfigurationVersion", ListAppConfigHostedConfigurationVersions)
+	registry.Register(&registry.Registration{
+		Name:     AppConfigHostedConfigurationVersionResource,
+		Scope:    nuke.Account,
+		Resource: &AppConfigHostedConfigurationVersion{},
+		Lister:   &AppConfigHostedConfigurationVersionLister{},
+	})
 }
 
-func ListAppConfigHostedConfigurationVersions(sess *session.Session) ([]Resource, error) {
-	svc := appconfig.New(sess)
-	resources := []Resource{}
-	configurationProfiles, err := ListAppConfigConfigurationProfiles(sess)
+type AppConfigHostedConfigurationVersionLister struct{}
+
+func (l *AppConfigHostedConfigurationVersionLister) List(ctx context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
+
+	svc := appconfig.New(opts.Session)
+	resources := make([]resource.Resource, 0)
+
+	profilerLister := &AppConfigConfigurationProfileLister{}
+	configurationProfiles, err := profilerLister.List(ctx, o)
 	if err != nil {
 		return nil, err
 	}
@@ -33,7 +46,7 @@ func ListAppConfigHostedConfigurationVersions(sess *session.Session) ([]Resource
 			continue
 		}
 		params := &appconfig.ListHostedConfigurationVersionsInput{
-			ApplicationId:          configurationProfile.applicationId,
+			ApplicationId:          configurationProfile.applicationID,
 			ConfigurationProfileId: configurationProfile.id,
 			MaxResults:             aws.Int64(50),
 		}
@@ -41,8 +54,8 @@ func ListAppConfigHostedConfigurationVersions(sess *session.Session) ([]Resource
 			for _, item := range page.Items {
 				resources = append(resources, &AppConfigHostedConfigurationVersion{
 					svc:                    svc,
-					applicationId:          configurationProfile.applicationId,
-					configurationProfileId: configurationProfile.id,
+					applicationID:          configurationProfile.applicationID,
+					configurationProfileID: configurationProfile.id,
 					versionNumber:          item.VersionNumber,
 				})
 			}
@@ -55,10 +68,17 @@ func ListAppConfigHostedConfigurationVersions(sess *session.Session) ([]Resource
 	return resources, nil
 }
 
-func (f *AppConfigHostedConfigurationVersion) Remove() error {
+type AppConfigHostedConfigurationVersion struct {
+	svc                    *appconfig.AppConfig
+	applicationID          *string
+	configurationProfileID *string
+	versionNumber          *int64
+}
+
+func (f *AppConfigHostedConfigurationVersion) Remove(_ context.Context) error {
 	_, err := f.svc.DeleteHostedConfigurationVersion(&appconfig.DeleteHostedConfigurationVersionInput{
-		ApplicationId:          f.applicationId,
-		ConfigurationProfileId: f.configurationProfileId,
+		ApplicationId:          f.applicationID,
+		ConfigurationProfileId: f.configurationProfileID,
 		VersionNumber:          f.versionNumber,
 	})
 	return err
@@ -66,7 +86,7 @@ func (f *AppConfigHostedConfigurationVersion) Remove() error {
 
 func (f *AppConfigHostedConfigurationVersion) Properties() types.Properties {
 	return types.NewProperties().
-		Set("ApplicationID", f.applicationId).
-		Set("ConfigurationProfileID", f.configurationProfileId).
+		Set("ApplicationID", f.applicationID).
+		Set("ConfigurationProfileID", f.configurationProfileID).
 		Set("VersionNumber", f.versionNumber)
 }
