@@ -1,24 +1,35 @@
 package resources
 
 import (
-	"github.com/aws/aws-sdk-go/aws/session"
+	"context"
+
 	"github.com/aws/aws-sdk-go/service/apprunner"
-	"github.com/rebuy-de/aws-nuke/v2/pkg/types"
+
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
+	"github.com/ekristen/libnuke/pkg/types"
+
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
 )
 
-type AppRunnerConnection struct {
-	svc            *apprunner.AppRunner
-	ConnectionArn  *string
-	ConnectionName *string
-}
+const AppRunnerConnectionResource = "AppRunnerConnection"
 
 func init() {
-	register("AppRunnerConnection", ListAppRunnerConnections)
+	registry.Register(&registry.Registration{
+		Name:     AppRunnerConnectionResource,
+		Scope:    nuke.Account,
+		Resource: &AppRunnerConnection{},
+		Lister:   &AppRunnerConnectionLister{},
+	})
 }
 
-func ListAppRunnerConnections(sess *session.Session) ([]Resource, error) {
-	svc := apprunner.New(sess)
-	resources := []Resource{}
+type AppRunnerConnectionLister struct{}
+
+func (l *AppRunnerConnectionLister) List(_ context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
+
+	svc := apprunner.New(opts.Session)
+	resources := make([]resource.Resource, 0)
 
 	params := &apprunner.ListConnectionsInput{}
 
@@ -46,7 +57,13 @@ func ListAppRunnerConnections(sess *session.Session) ([]Resource, error) {
 	return resources, nil
 }
 
-func (f *AppRunnerConnection) Remove() error {
+type AppRunnerConnection struct {
+	svc            *apprunner.AppRunner
+	ConnectionArn  *string
+	ConnectionName *string
+}
+
+func (f *AppRunnerConnection) Remove(_ context.Context) error {
 	_, err := f.svc.DeleteConnection(&apprunner.DeleteConnectionInput{
 		ConnectionArn: f.ConnectionArn,
 	})
