@@ -1,23 +1,35 @@
 package resources
 
 import (
+	"context"
+
 	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/appstream"
+
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
+
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
 )
 
-type AppStreamDirectoryConfig struct {
-	svc  *appstream.AppStream
-	name *string
-}
+const AppStreamDirectoryConfigResource = "AppStreamDirectoryConfig"
 
 func init() {
-	register("AppStreamDirectoryConfig", ListAppStreamDirectoryConfigs)
+	registry.Register(&registry.Registration{
+		Name:     AppStreamDirectoryConfigResource,
+		Scope:    nuke.Account,
+		Resource: &AppStreamDirectoryConfig{},
+		Lister:   &AppStreamDirectoryConfigLister{},
+	})
 }
 
-func ListAppStreamDirectoryConfigs(sess *session.Session) ([]Resource, error) {
-	svc := appstream.New(sess)
-	resources := []Resource{}
+type AppStreamDirectoryConfigLister struct{}
+
+func (l *AppStreamDirectoryConfigLister) List(_ context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
+
+	svc := appstream.New(opts.Session)
+	resources := make([]resource.Resource, 0)
 
 	params := &appstream.DescribeDirectoryConfigsInput{
 		MaxResults: aws.Int64(100),
@@ -46,8 +58,12 @@ func ListAppStreamDirectoryConfigs(sess *session.Session) ([]Resource, error) {
 	return resources, nil
 }
 
-func (f *AppStreamDirectoryConfig) Remove() error {
+type AppStreamDirectoryConfig struct {
+	svc  *appstream.AppStream
+	name *string
+}
 
+func (f *AppStreamDirectoryConfig) Remove(_ context.Context) error {
 	_, err := f.svc.DeleteDirectoryConfig(&appstream.DeleteDirectoryConfigInput{
 		DirectoryName: f.name,
 	})
