@@ -1,26 +1,38 @@
 package resources
 
 import (
+	"context"
 	"fmt"
 	"strings"
 
-	"github.com/aws/aws-sdk-go/aws/session"
+	"github.com/gotidy/ptr"
+
 	"github.com/aws/aws-sdk-go/service/appstream"
+
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
+
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
 )
 
-type AppStreamImage struct {
-	svc        *appstream.AppStream
-	name       *string
-	visibility *string
-}
+const AppStreamImageResource = "AppStreamImage"
 
 func init() {
-	register("AppStreamImage", ListAppStreamImages)
+	registry.Register(&registry.Registration{
+		Name:     AppStreamImageResource,
+		Scope:    nuke.Account,
+		Resource: &AppStreamImage{},
+		Lister:   &AppStreamImageLister{},
+	})
 }
 
-func ListAppStreamImages(sess *session.Session) ([]Resource, error) {
-	svc := appstream.New(sess)
-	resources := []Resource{}
+type AppStreamImageLister struct{}
+
+func (l *AppStreamImageLister) List(_ context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
+
+	svc := appstream.New(opts.Session)
+	resources := make([]resource.Resource, 0)
 
 	params := &appstream.DescribeImagesInput{}
 
@@ -40,8 +52,13 @@ func ListAppStreamImages(sess *session.Session) ([]Resource, error) {
 	return resources, nil
 }
 
-func (f *AppStreamImage) Remove() error {
+type AppStreamImage struct {
+	svc        *appstream.AppStream
+	name       *string
+	visibility *string
+}
 
+func (f *AppStreamImage) Remove(_ context.Context) error {
 	_, err := f.svc.DeleteImage(&appstream.DeleteImageInput{
 		Name: f.name,
 	})
@@ -54,7 +71,7 @@ func (f *AppStreamImage) String() string {
 }
 
 func (f *AppStreamImage) Filter() error {
-	if strings.ToUpper(*f.visibility) == "PUBLIC" {
+	if strings.EqualFold(ptr.ToString(f.visibility), "PUBLIC") {
 		return fmt.Errorf("cannot delete public AWS images")
 	}
 	return nil
