@@ -1,36 +1,48 @@
 package resources
 
 import (
-	"fmt"
-	"github.com/aws/aws-sdk-go/aws/session"
+	"context"
+
 	"github.com/aws/aws-sdk-go/service/backup"
-	"github.com/rebuy-de/aws-nuke/v2/pkg/types"
+
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
+	"github.com/ekristen/libnuke/pkg/types"
+
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
 )
 
-type BackupRecoveryPoint struct {
-	svc             *backup.Backup
-	arn             string
-	backupVaultName string
-}
+const AWSBackupRecoveryPointResource = "AWSBackupRecoveryPoint"
 
 func init() {
-	register("AWSBackupRecoveryPoint", ListBackupRecoveryPoints)
+	registry.Register(&registry.Registration{
+		Name:     AWSBackupRecoveryPointResource,
+		Scope:    nuke.Account,
+		Resource: &BackupRecoveryPoint{},
+		Lister:   &AWSBackupRecoveryPointLister{},
+	})
 }
 
-func ListBackupRecoveryPoints(sess *session.Session) ([]Resource, error) {
-	svc := backup.New(sess)
-	max_vaults_len := int64(100)
+type AWSBackupRecoveryPointLister struct{}
+
+func (l *AWSBackupRecoveryPointLister) List(_ context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
+
+	svc := backup.New(opts.Session)
+	maxVaultsLen := int64(100)
 	params := &backup.ListBackupVaultsInput{
-		MaxResults: &max_vaults_len, // aws default limit on number of backup vaults per account
+		MaxResults: &maxVaultsLen, // aws default limit on number of backup vaults per account
 	}
 	resp, err := svc.ListBackupVaults(params)
 	if err != nil {
 		return nil, err
 	}
 
-	resources := make([]Resource, 0)
+	resources := make([]resource.Resource, 0)
 	for _, out := range resp.BackupVaultList {
-		recoveryPointsOutput, _ := svc.ListRecoveryPointsByBackupVault(&backup.ListRecoveryPointsByBackupVaultInput{BackupVaultName: out.BackupVaultName})
+		recoveryPointsOutput, _ := svc.ListRecoveryPointsByBackupVault(
+			&backup.ListRecoveryPointsByBackupVaultInput{BackupVaultName: out.BackupVaultName})
+
 		for _, rp := range recoveryPointsOutput.RecoveryPoints {
 			resources = append(resources, &BackupRecoveryPoint{
 				svc:             svc,
@@ -43,13 +55,19 @@ func ListBackupRecoveryPoints(sess *session.Session) ([]Resource, error) {
 	return resources, nil
 }
 
+type BackupRecoveryPoint struct {
+	svc             *backup.Backup
+	arn             string
+	backupVaultName string
+}
+
 func (b *BackupRecoveryPoint) Properties() types.Properties {
 	properties := types.NewProperties()
 	properties.Set("BackupVault", b.backupVaultName)
 	return properties
 }
 
-func (b *BackupRecoveryPoint) Remove() error {
+func (b *BackupRecoveryPoint) Remove(_ context.Context) error {
 	_, err := b.svc.DeleteRecoveryPoint(&backup.DeleteRecoveryPointInput{
 		BackupVaultName:  &b.backupVaultName,
 		RecoveryPointArn: &b.arn,
@@ -58,5 +76,5 @@ func (b *BackupRecoveryPoint) Remove() error {
 }
 
 func (b *BackupRecoveryPoint) String() string {
-	return fmt.Sprintf("%s", b.arn)
+	return b.arn
 }
