@@ -1,23 +1,35 @@
 package resources
 
 import (
+	"context"
+
 	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/databasemigrationservice"
+
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
+
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
 )
 
-type DatabaseMigrationServiceEndpoint struct {
-	svc *databasemigrationservice.DatabaseMigrationService
-	ARN *string
-}
+const DatabaseMigrationServiceEndpointResource = "DatabaseMigrationServiceEndpoint"
 
 func init() {
-	register("DatabaseMigrationServiceEndpoint", ListDatabaseMigrationServiceEndpoints)
+	registry.Register(&registry.Registration{
+		Name:     DatabaseMigrationServiceEndpointResource,
+		Scope:    nuke.Account,
+		Resource: &DatabaseMigrationServiceEndpoint{},
+		Lister:   &DatabaseMigrationServiceEndpointLister{},
+	})
 }
 
-func ListDatabaseMigrationServiceEndpoints(sess *session.Session) ([]Resource, error) {
-	svc := databasemigrationservice.New(sess)
-	resources := []Resource{}
+type DatabaseMigrationServiceEndpointLister struct{}
+
+func (l *DatabaseMigrationServiceEndpointLister) List(_ context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
+
+	svc := databasemigrationservice.New(opts.Session)
+	resources := make([]resource.Resource, 0)
 
 	params := &databasemigrationservice.DescribeEndpointsInput{
 		MaxRecords: aws.Int64(100),
@@ -46,8 +58,12 @@ func ListDatabaseMigrationServiceEndpoints(sess *session.Session) ([]Resource, e
 	return resources, nil
 }
 
-func (f *DatabaseMigrationServiceEndpoint) Remove() error {
+type DatabaseMigrationServiceEndpoint struct {
+	svc *databasemigrationservice.DatabaseMigrationService
+	ARN *string
+}
 
+func (f *DatabaseMigrationServiceEndpoint) Remove(_ context.Context) error {
 	_, err := f.svc.DeleteEndpoint(&databasemigrationservice.DeleteEndpointInput{
 		EndpointArn: f.ARN,
 	})
