@@ -1,25 +1,36 @@
 package resources
 
 import (
+	"context"
+
 	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/elasticbeanstalk"
-	"github.com/rebuy-de/aws-nuke/v2/pkg/types"
+
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
+	"github.com/ekristen/libnuke/pkg/types"
+
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
 )
 
-type ElasticBeanstalkEnvironment struct {
-	svc  *elasticbeanstalk.ElasticBeanstalk
-	ID   *string
-	name *string
-}
+const ElasticBeanstalkEnvironmentResource = "ElasticBeanstalkEnvironment"
 
 func init() {
-	register("ElasticBeanstalkEnvironment", ListElasticBeanstalkEnvironments)
+	registry.Register(&registry.Registration{
+		Name:     ElasticBeanstalkEnvironmentResource,
+		Scope:    nuke.Account,
+		Resource: &ElasticBeanstalkEnvironment{},
+		Lister:   &ElasticBeanstalkEnvironmentLister{},
+	})
 }
 
-func ListElasticBeanstalkEnvironments(sess *session.Session) ([]Resource, error) {
-	svc := elasticbeanstalk.New(sess)
-	resources := []Resource{}
+type ElasticBeanstalkEnvironmentLister struct{}
+
+func (l *ElasticBeanstalkEnvironmentLister) List(_ context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
+
+	svc := elasticbeanstalk.New(opts.Session)
+	resources := make([]resource.Resource, 0)
 
 	params := &elasticbeanstalk.DescribeEnvironmentsInput{
 		MaxRecords:     aws.Int64(100),
@@ -50,8 +61,13 @@ func ListElasticBeanstalkEnvironments(sess *session.Session) ([]Resource, error)
 	return resources, nil
 }
 
-func (f *ElasticBeanstalkEnvironment) Remove() error {
+type ElasticBeanstalkEnvironment struct {
+	svc  *elasticbeanstalk.ElasticBeanstalk
+	ID   *string
+	name *string
+}
 
+func (f *ElasticBeanstalkEnvironment) Remove(_ context.Context) error {
 	_, err := f.svc.TerminateEnvironment(&elasticbeanstalk.TerminateEnvironmentInput{
 		EnvironmentId:      f.ID,
 		ForceTerminate:     aws.Bool(true),
@@ -61,9 +77,9 @@ func (f *ElasticBeanstalkEnvironment) Remove() error {
 	return err
 }
 
-func (e *ElasticBeanstalkEnvironment) Properties() types.Properties {
+func (f *ElasticBeanstalkEnvironment) Properties() types.Properties {
 	return types.NewProperties().
-		Set("Name", e.name)
+		Set("Name", f.name)
 }
 
 func (f *ElasticBeanstalkEnvironment) String() string {
