@@ -1,23 +1,35 @@
 package resources
 
 import (
+	"context"
+
 	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/gluedatabrew"
+
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
+
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
 )
 
-type GlueDataBrewProjects struct {
-	svc  *gluedatabrew.GlueDataBrew
-	name *string
-}
+const GlueDataBrewProjectsResource = "GlueDataBrewProjects"
 
 func init() {
-	register("GlueDataBrewProjects", ListGlueDataBrewProjects)
+	registry.Register(&registry.Registration{
+		Name:     GlueDataBrewProjectsResource,
+		Scope:    nuke.Account,
+		Resource: &GlueDataBrewProjects{},
+		Lister:   &GlueDataBrewProjectsLister{},
+	})
 }
 
-func ListGlueDataBrewProjects(sess *session.Session) ([]Resource, error) {
-	svc := gluedatabrew.New(sess)
-	resources := []Resource{}
+type GlueDataBrewProjectsLister struct{}
+
+func (l *GlueDataBrewProjectsLister) List(_ context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
+
+	svc := gluedatabrew.New(opts.Session)
+	resources := make([]resource.Resource, 0)
 
 	params := &gluedatabrew.ListProjectsInput{
 		MaxResults: aws.Int64(100),
@@ -46,7 +58,12 @@ func ListGlueDataBrewProjects(sess *session.Session) ([]Resource, error) {
 	return resources, nil
 }
 
-func (f *GlueDataBrewProjects) Remove() error {
+type GlueDataBrewProjects struct {
+	svc  *gluedatabrew.GlueDataBrew
+	name *string
+}
+
+func (f *GlueDataBrewProjects) Remove(_ context.Context) error {
 	_, err := f.svc.DeleteProject(&gluedatabrew.DeleteProjectInput{
 		Name: f.name,
 	})
