@@ -1,32 +1,92 @@
 package resources
 
 import (
+	"context"
 	"fmt"
 	"strings"
-	"time"
 
 	"github.com/sirupsen/logrus"
 
-	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/iam"
-	"github.com/rebuy-de/aws-nuke/v2/pkg/types"
+	"github.com/aws/aws-sdk-go/service/iam/iamiface"
+
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
+	"github.com/ekristen/libnuke/pkg/types"
+
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
 )
 
-type IAMRolePolicy struct {
-	svc        *iam.IAM
-	role       iam.Role
-	policyName string
-}
+const IAMRolePolicyResource = "IAMRolePolicy"
 
 func init() {
-	register("IAMRolePolicy", ListIAMRolePolicies)
+	registry.Register(&registry.Registration{
+		Name:     IAMRolePolicyResource,
+		Scope:    nuke.Account,
+		Resource: &IAMRolePolicy{},
+		Lister:   &IAMRolePolicyLister{},
+	})
 }
 
-func ListIAMRolePolicies(sess *session.Session) ([]Resource, error) {
-	svc := iam.New(sess)
+type IAMRolePolicy struct {
+	svc        iamiface.IAMAPI
+	roleID     string
+	rolePath   string
+	roleName   string
+	policyName string
+	roleTags   []*iam.Tag
+}
+
+func (e *IAMRolePolicy) Filter() error {
+	if strings.HasPrefix(e.rolePath, "/aws-service-role/") {
+		return fmt.Errorf("cannot alter service roles")
+	}
+	if strings.HasPrefix(e.rolePath, "/aws-reserved/sso.amazonaws.com/") {
+		return fmt.Errorf("cannot alter sso roles")
+	}
+	return nil
+}
+
+func (e *IAMRolePolicy) Remove(_ context.Context) error {
+	_, err := e.svc.DeleteRolePolicy(
+		&iam.DeleteRolePolicyInput{
+			RoleName:   &e.roleName,
+			PolicyName: &e.policyName,
+		})
+	if err != nil {
+		return err
+	}
+
+	return nil
+}
+
+func (e *IAMRolePolicy) Properties() types.Properties {
+	properties := types.NewProperties()
+	properties.Set("PolicyName", e.policyName)
+	properties.Set("role:RoleName", e.roleName)
+	properties.Set("role:RoleID", e.roleID)
+	properties.Set("role:Path", e.rolePath)
+
+	for _, tagValue := range e.roleTags {
+		properties.SetTagWithPrefix("role", tagValue.Key, tagValue.Value)
+	}
+	return properties
+}
+
+func (e *IAMRolePolicy) String() string {
+	return fmt.Sprintf("%s -> %s", e.roleName, e.policyName)
+}
+
+// ----------------------
+
+type IAMRolePolicyLister struct{}
+
+func (l *IAMRolePolicyLister) List(_ context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
+
+	svc := iam.New(opts.Session)
 	roleParams := &iam.ListRolesInput{}
-	resources := make([]Resource, 0)
+	resources := make([]resource.Resource, 0)
 
 	for {
 		roles, err := svc.ListRoles(roleParams)
@@ -58,8 +118,11 @@ func ListIAMRolePolicies(sess *session.Session) ([]Resource, error) {
 				for _, policyName := range policies.PolicyNames {
 					resources = append(resources, &IAMRolePolicy{
 						svc:        svc,
-						role:       *role,
+						roleID:     *role.RoleId,
+						roleName:   *role.RoleName,
+						rolePath:   *role.Path,
 						policyName: *policyName,
+						roleTags:   role.Tags,
 					})
 				}
 
@@ -80,42 +143,3 @@ func ListIAMRolePolicies(sess *session.Session) ([]Resource, error) {
 
 	return resources, nil
 }
-
-func (e *IAMRolePolicy) Filter() error {
-	if strings.HasPrefix(aws.StringValue(e.role.Path), "/aws-service-role/") {
-		return fmt.Errorf("cannot alter service roles")
-	}
-	return nil
-}
-
-func (e *IAMRolePolicy) Remove() error {
-	_, err := e.svc.DeleteRolePolicy(
-		&iam.DeleteRolePolicyInput{
-			RoleName:   e.role.RoleName,
-			PolicyName: &e.policyName,
-		})
-	if err != nil {
-		return err
-	}
-
-	return nil
-}
-
-func (e *IAMRolePolicy) Properties() types.Properties {
-	properties := types.NewProperties().
-		Set("PolicyName", e.policyName).
-		Set("role:RoleName", e.role.RoleName).
-		Set("role:RoleID", e.role.RoleId).
-		Set("role:Path", e.role.Path).
-		Set("role:LastUsed", getLastUsedDate(&e.role, time.RFC3339)).
-		Set("role:CreateDate", e.role.CreateDate.Format(time.RFC3339))
-
-	for _, tagValue := range e.role.Tags {
-		properties.SetTagWithPrefix("role", tagValue.Key, tagValue.Value)
-	}
-	return properties
-}
-
-func (e *IAMRolePolicy) String() string {
-	return fmt.Sprintf("%s -> %s", aws.StringValue(e.role.RoleName), e.policyName)
-}
