@@ -1,36 +1,35 @@
 package resources
 
 import (
+	"context"
+
 	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/mediaconvert"
+
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
+
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
 )
 
-type MediaConvertPreset struct {
-	svc  *mediaconvert.MediaConvert
-	name *string
-}
+const MediaConvertPresetResource = "MediaConvertPreset"
 
 func init() {
-	register("MediaConvertPreset", ListMediaConvertPresets)
+	registry.Register(&registry.Registration{
+		Name:     MediaConvertPresetResource,
+		Scope:    nuke.Account,
+		Resource: &MediaConvertPreset{},
+		Lister:   &MediaConvertPresetLister{},
+	})
 }
 
-func ListMediaConvertPresets(sess *session.Session) ([]Resource, error) {
-	svc := mediaconvert.New(sess)
-	resources := []Resource{}
-	var mediaEndpoint *string
+type MediaConvertPresetLister struct{}
 
-	output, err := svc.DescribeEndpoints(&mediaconvert.DescribeEndpointsInput{})
-	if err != nil {
-		return nil, err
-	}
+func (l *MediaConvertPresetLister) List(_ context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
 
-	for _, mediaconvert := range output.Endpoints {
-		mediaEndpoint = mediaconvert.Url
-	}
-
-	// Update svc to use custom media endpoint
-	svc.Endpoint = *mediaEndpoint
+	svc := mediaconvert.New(opts.Session)
+	resources := make([]resource.Resource, 0)
 
 	params := &mediaconvert.ListPresetsInput{
 		MaxResults: aws.Int64(20),
@@ -59,8 +58,12 @@ func ListMediaConvertPresets(sess *session.Session) ([]Resource, error) {
 	return resources, nil
 }
 
-func (f *MediaConvertPreset) Remove() error {
+type MediaConvertPreset struct {
+	svc  *mediaconvert.MediaConvert
+	name *string
+}
 
+func (f *MediaConvertPreset) Remove(_ context.Context) error {
 	_, err := f.svc.DeletePreset(&mediaconvert.DeletePresetInput{
 		Name: f.name,
 	})
