@@ -1,23 +1,35 @@
 package resources
 
 import (
-	"github.com/aws/aws-sdk-go/aws/session"
+	"context"
+
 	"github.com/aws/aws-sdk-go/service/redshift"
-	"github.com/rebuy-de/aws-nuke/v2/pkg/types"
+
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
+	"github.com/ekristen/libnuke/pkg/types"
+
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
 )
 
-type RedshiftScheduledAction struct {
-	svc                 *redshift.Redshift
-	scheduledActionName *string
-}
+const RedshiftScheduledActionResource = "RedshiftScheduledAction"
 
 func init() {
-	register("RedshiftScheduledAction", ListRedshiftScheduledActions)
+	registry.Register(&registry.Registration{
+		Name:     RedshiftScheduledActionResource,
+		Scope:    nuke.Account,
+		Resource: &RedshiftScheduledAction{},
+		Lister:   &RedshiftScheduledActionLister{},
+	})
 }
 
-func ListRedshiftScheduledActions(sess *session.Session) ([]Resource, error) {
-	svc := redshift.New(sess)
-	resources := []Resource{}
+type RedshiftScheduledActionLister struct{}
+
+func (l *RedshiftScheduledActionLister) List(_ context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
+
+	svc := redshift.New(opts.Session)
+	resources := make([]resource.Resource, 0)
 
 	params := &redshift.DescribeScheduledActionsInput{}
 
@@ -44,8 +56,12 @@ func ListRedshiftScheduledActions(sess *session.Session) ([]Resource, error) {
 	return resources, nil
 }
 
-func (f *RedshiftScheduledAction) Remove() error {
+type RedshiftScheduledAction struct {
+	svc                 *redshift.Redshift
+	scheduledActionName *string
+}
 
+func (f *RedshiftScheduledAction) Remove(_ context.Context) error {
 	_, err := f.svc.DeleteScheduledAction(&redshift.DeleteScheduledActionInput{
 		ScheduledActionName: f.scheduledActionName,
 	})
