@@ -1,30 +1,38 @@
 package resources
 
 import (
+	"context"
+
 	"fmt"
 
 	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/sagemaker"
-	"github.com/rebuy-de/aws-nuke/v2/pkg/types"
+
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
+	"github.com/ekristen/libnuke/pkg/types"
+
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
 )
 
-type SageMakerApp struct {
-	svc             *sagemaker.SageMaker
-	domainID        *string
-	appName         *string
-	appType         *string
-	userProfileName *string
-	status          *string
-}
+const SageMakerAppResource = "SageMakerApp"
 
 func init() {
-	register("SageMakerApp", ListSageMakerApps)
+	registry.Register(&registry.Registration{
+		Name:     SageMakerAppResource,
+		Scope:    nuke.Account,
+		Resource: &SageMakerApp{},
+		Lister:   &SageMakerAppLister{},
+	})
 }
 
-func ListSageMakerApps(sess *session.Session) ([]Resource, error) {
-	svc := sagemaker.New(sess)
-	resources := []Resource{}
+type SageMakerAppLister struct{}
+
+func (l *SageMakerAppLister) List(_ context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
+
+	svc := sagemaker.New(opts.Session)
+	resources := make([]resource.Resource, 0)
 
 	params := &sagemaker.ListAppsInput{
 		MaxResults: aws.Int64(30),
@@ -43,6 +51,7 @@ func ListSageMakerApps(sess *session.Session) ([]Resource, error) {
 				appName:         app.AppName,
 				appType:         app.AppType,
 				userProfileName: app.UserProfileName,
+				spaceName:       app.SpaceName,
 				status:          app.Status,
 			})
 		}
@@ -57,12 +66,23 @@ func ListSageMakerApps(sess *session.Session) ([]Resource, error) {
 	return resources, nil
 }
 
-func (f *SageMakerApp) Remove() error {
+type SageMakerApp struct {
+	svc             *sagemaker.SageMaker
+	domainID        *string
+	appName         *string
+	appType         *string
+	userProfileName *string
+	spaceName       *string
+	status          *string
+}
+
+func (f *SageMakerApp) Remove(_ context.Context) error {
 	_, err := f.svc.DeleteApp(&sagemaker.DeleteAppInput{
 		DomainId:        f.domainID,
 		AppName:         f.appName,
 		AppType:         f.appType,
 		UserProfileName: f.userProfileName,
+		SpaceName:       f.spaceName,
 	})
 
 	return err
@@ -72,13 +92,14 @@ func (f *SageMakerApp) String() string {
 	return *f.appName
 }
 
-func (i *SageMakerApp) Properties() types.Properties {
+func (f *SageMakerApp) Properties() types.Properties {
 	properties := types.NewProperties()
 	properties.
-		Set("DomainID", i.domainID).
-		Set("AppName", i.appName).
-		Set("AppType", i.appType).
-		Set("UserProfileName", i.userProfileName)
+		Set("DomainID", f.domainID).
+		Set("AppName", f.appName).
+		Set("AppType", f.appType).
+		Set("UserProfileName", f.userProfileName).
+		Set("SpaceName", f.spaceName)
 	return properties
 }
 
