@@ -1,27 +1,39 @@
 package resources
 
 import (
+	"context"
+
+	"github.com/sirupsen/logrus"
+
 	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/servicecatalog"
-	"github.com/rebuy-de/aws-nuke/v2/pkg/types"
-	log "github.com/sirupsen/logrus"
+
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
+	"github.com/ekristen/libnuke/pkg/types"
+
+	"github.com/ekristen/aws-nuke/v3/pkg/awsutil"
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
 )
 
-type ServiceCatalogTagOption struct {
-	svc   *servicecatalog.ServiceCatalog
-	ID    *string
-	key   *string
-	value *string
-}
+const ServiceCatalogTagOptionResource = "ServiceCatalogTagOption"
 
 func init() {
-	register("ServiceCatalogTagOption", ListServiceCatalogTagOptions)
+	registry.Register(&registry.Registration{
+		Name:     ServiceCatalogTagOptionResource,
+		Scope:    nuke.Account,
+		Resource: &ServiceCatalogTagOption{},
+		Lister:   &ServiceCatalogTagOptionLister{},
+	})
 }
 
-func ListServiceCatalogTagOptions(sess *session.Session) ([]Resource, error) {
-	svc := servicecatalog.New(sess)
-	resources := []Resource{}
+type ServiceCatalogTagOptionLister struct{}
+
+func (l *ServiceCatalogTagOptionLister) List(_ context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
+
+	svc := servicecatalog.New(opts.Session)
+	resources := make([]resource.Resource, 0)
 
 	params := &servicecatalog.ListTagOptionsInput{
 		PageSize: aws.Int64(20),
@@ -30,8 +42,8 @@ func ListServiceCatalogTagOptions(sess *session.Session) ([]Resource, error) {
 	for {
 		resp, err := svc.ListTagOptions(params)
 		if err != nil {
-			if IsAWSError(err, servicecatalog.ErrCodeTagOptionNotMigratedException) {
-				log.Info(err)
+			if awsutil.IsAWSError(err, servicecatalog.ErrCodeTagOptionNotMigratedException) {
+				logrus.Info(err)
 				break
 			}
 			return nil, err
@@ -56,8 +68,14 @@ func ListServiceCatalogTagOptions(sess *session.Session) ([]Resource, error) {
 	return resources, nil
 }
 
-func (f *ServiceCatalogTagOption) Remove() error {
+type ServiceCatalogTagOption struct {
+	svc   *servicecatalog.ServiceCatalog
+	ID    *string
+	key   *string
+	value *string
+}
 
+func (f *ServiceCatalogTagOption) Remove(_ context.Context) error {
 	_, err := f.svc.DeleteTagOption(&servicecatalog.DeleteTagOptionInput{
 		Id: f.ID,
 	})
