@@ -1,24 +1,35 @@
 package resources
 
 import (
+	"context"
+
 	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/ssm"
+
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
+
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
 )
 
-type SSMAssociation struct {
-	svc           *ssm.SSM
-	associationID *string
-	instanceID    *string
-}
+const SSMAssociationResource = "SSMAssociation"
 
 func init() {
-	register("SSMAssociation", ListSSMAssociations)
+	registry.Register(&registry.Registration{
+		Name:     SSMAssociationResource,
+		Scope:    nuke.Account,
+		Resource: &SSMAssociation{},
+		Lister:   &SSMAssociationLister{},
+	})
 }
 
-func ListSSMAssociations(sess *session.Session) ([]Resource, error) {
-	svc := ssm.New(sess)
-	resources := []Resource{}
+type SSMAssociationLister struct{}
+
+func (l *SSMAssociationLister) List(_ context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
+
+	svc := ssm.New(opts.Session)
+	resources := make([]resource.Resource, 0)
 
 	params := &ssm.ListAssociationsInput{
 		MaxResults: aws.Int64(50),
@@ -48,8 +59,13 @@ func ListSSMAssociations(sess *session.Session) ([]Resource, error) {
 	return resources, nil
 }
 
-func (f *SSMAssociation) Remove() error {
+type SSMAssociation struct {
+	svc           *ssm.SSM
+	associationID *string
+	instanceID    *string
+}
 
+func (f *SSMAssociation) Remove(_ context.Context) error {
 	_, err := f.svc.DeleteAssociation(&ssm.DeleteAssociationInput{
 		AssociationId: f.associationID,
 	})
