@@ -1,23 +1,35 @@
 package resources
 
 import (
+	"context"
+
 	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/waf"
+
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
+
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
 )
 
-type WAFWebACL struct {
-	svc *waf.WAF
-	ID  *string
-}
+const WAFWebACLResource = "WAFWebACL"
 
 func init() {
-	register("WAFWebACL", ListWAFWebACLs)
+	registry.Register(&registry.Registration{
+		Name:     WAFWebACLResource,
+		Scope:    nuke.Account,
+		Resource: &WAFWebACL{},
+		Lister:   &WAFWebACLLister{},
+	})
 }
 
-func ListWAFWebACLs(sess *session.Session) ([]Resource, error) {
-	svc := waf.New(sess)
-	resources := []Resource{}
+type WAFWebACLLister struct{}
+
+func (l *WAFWebACLLister) List(_ context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
+
+	svc := waf.New(opts.Session)
+	resources := make([]resource.Resource, 0)
 
 	params := &waf.ListWebACLsInput{
 		Limit: aws.Int64(50),
@@ -46,8 +58,12 @@ func ListWAFWebACLs(sess *session.Session) ([]Resource, error) {
 	return resources, nil
 }
 
-func (f *WAFWebACL) Remove() error {
+type WAFWebACL struct {
+	svc *waf.WAF
+	ID  *string
+}
 
+func (f *WAFWebACL) Remove(_ context.Context) error {
 	tokenOutput, err := f.svc.GetChangeToken(&waf.GetChangeTokenInput{})
 	if err != nil {
 		return err
